@@ -7,7 +7,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,6 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
 #include <gnome.h>
 #include "dialogs.h"
 #include "main.h"
@@ -36,21 +35,39 @@ static GtkWidget *about = NULL;
 
 void
 oregano_error (gchar *msg)
+{
+    oregano_error_with_title(msg, NULL);
+}
+
+void
+oregano_error_with_title (gchar *title, gchar *desc)
 {
 	GtkWidget *dialog;
 	gint result;
 
+	GString* span_msg;
+
+	span_msg = g_string_new("<span weight=\"bold\" size=\"large\">");
+	span_msg = g_string_append(span_msg, title);
+	span_msg = g_string_append(span_msg,"</span>");
+
+	if (desc && desc[0] != '\0') {
+		span_msg = g_string_append(span_msg,"\n\n");
+		span_msg = g_string_append(span_msg, desc);
+	}
+
 	dialog = gtk_message_dialog_new_with_markup (
 		NULL,
 		GTK_DIALOG_MODAL,
 		GTK_MESSAGE_ERROR,
 		GTK_BUTTONS_OK,
-		msg);
+		span_msg->str);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
 
+	g_string_free(span_msg, TRUE);
 	gtk_widget_destroy (dialog);
 }
 
@@ -85,7 +102,7 @@ void
 dialog_about (void)
 {
 	GdkPixbuf *logo;
-	GError *error;
+	GError *error = NULL;
 
 	const gchar *authors[] = {
 		"Margarita Manterola",
@@ -106,7 +123,7 @@ dialog_about (void)
 		NULL
 	};
 
-	const gchar *copy = _("(c) 2003-2005 LUGFi\n(c) 1999-2001 Richard Hult");
+	const gchar *copy = _("(c) 2003-2006 LUGFi\n(c) 1999-2001 Richard Hult");
 
 	/* Allow only one about box at a time. */
 	if (about){
