@@ -38,7 +38,6 @@
 #include "wire.h"
 #include "wire-private.h"
 #include "item-data.h"
-#include "print.h"
 
 /*
  * NODE_EPSILON is used to check for intersection.
@@ -1140,8 +1139,22 @@ node_store_count_items (NodeStore *store, ArtDRect *rect)
 	return n;
 }
 
+static void
+draw_dot (SheetPos *key, Node *value, cairo_t *cr)
+{
+	if (node_needs_dot (value)) {
+		cairo_save (cr);
+			cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+			cairo_translate (cr, key->x, key->y);
+			cairo_scale (cr, 1.0, 1.0);
+			cairo_arc (cr, 0.0, 0.0, 1.0, 0.0, 2 * M_PI);
+			cairo_fill (cr);
+		cairo_restore (cr);
+	}
+}
+
 void
-node_store_print_items (NodeStore *store, OreganoPrintContext *opc, ArtDRect *rect)
+node_store_print_items (NodeStore *store, cairo_t *cr, SchematicPrintContext *ctx)
 {
 	GList *list;
 	SheetPos p1, p2;
@@ -1149,23 +1162,20 @@ node_store_print_items (NodeStore *store, OreganoPrintContext *opc, ArtDRect *re
 
 	g_return_if_fail (store != NULL);
 	g_return_if_fail (IS_NODE_STORE (store));
-	g_return_if_fail (rect != NULL);
 
+	cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
 	for (list = store->items; list; list = list->next) {
 		data = ITEM_DATA (list->data);
-		item_data_get_absolute_bbox (data, &p1, &p2);
-//		if (p1.x >= rect->x0 && p1.y >= rect->y0 && p2.x <= rect->x1 && p2.y <= rect->y1) {
-		if ((p1.x <= rect->x1) && (p1.y <= rect->y1) &&
-			(p2.x >= rect->x0) && (p2.y >= rect->y0)) {
-			item_data_print (data, opc);
-		}
+		item_data_print (data, cr, ctx);
 	}
+
+	g_hash_table_foreach (store->nodes, (GHFunc)draw_dot, cr);
 }
 
 void
-node_store_print_labels (NodeStore *store, OreganoPrintContext *opc, ArtDRect *rect)
+node_store_print_labels (NodeStore *store, cairo_t *opc, ArtDRect *rect)
 {
-	GList *list;
+/*	GList *list;
 	SheetPos p1, p2;
 	ItemData *data;
 
@@ -1182,6 +1192,7 @@ node_store_print_labels (NodeStore *store, OreganoPrintContext *opc, ArtDRect *r
 			item_data_print (data, opc);
 		}
 	}
+*/
 }
 
 int
