@@ -30,6 +30,7 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glade/glade.h>
 #include "schematic.h"
 #include "node-store.h"
 //#include "load-schematic.h"
@@ -38,6 +39,15 @@
 #include "sim-settings.h"
 #include "simulation.h"
 #include "errors.h"
+#include "schematic-print-context.h"
+
+typedef struct _SchematicsPrintOptions {
+	GtkColorButton *components;
+	GtkColorButton *labels;
+	GtkColorButton *wires;
+	GtkColorButton *text;
+	GtkColorButton *background;
+} SchematicPrintOptions;
 
 struct _SchematicPriv {
 	char *title;
@@ -46,6 +56,9 @@ struct _SchematicPriv {
 	char *comments;
 	char *netlist_filename;
 
+	SchematicColors colors;
+	SchematicPrintOptions *printoptions;
+
 	/*
 	 * Data for various dialogs.
 	 */
@@ -223,6 +236,21 @@ schematic_init(Schematic *schematic)
 
 	priv = schematic->priv = g_new0 (SchematicPriv, 1);
 
+	priv->printoptions = NULL;
+	/* Colors */
+	priv->colors.components.red = 65535;
+	priv->colors.components.green = 0;
+	priv->colors.components.blue = 0;
+	priv->colors.labels.red = 0;
+	priv->colors.labels.green = 35723;
+	priv->colors.labels.blue = 35723;
+	priv->colors.wires.red = 0;
+	priv->colors.wires.green = 0;
+	priv->colors.wires.blue = 65535;
+	priv->colors.text.red = 0;
+	priv->colors.text.green = 0;
+	priv->colors.text.blue = 0;
+
 	priv->symbols = g_hash_table_new (g_str_hash, g_str_equal);
 	/* FIXME: use own str_equal (lib::sym)*/
 	priv->refdes_values = g_hash_table_new (g_str_hash, g_str_equal);
@@ -603,7 +631,7 @@ schematic_read (char *name, GError **out_error)
 	if (error != NULL) {
 		g_propagate_error (out_error, error);
 		g_object_unref(G_OBJECT(new_sm));
-		return;
+		return NULL;
 	}
 
 	if (ret) {
@@ -630,7 +658,7 @@ schematic_save_file (Schematic *sm, GError **error)
 	if (ft == NULL) {
 		g_set_error (error, OREGANO_ERROR, OREGANO_SCHEMATIC_FILE_NOT_FOUND,
 			_("Unknown file format for %s."), schematic_get_filename (sm));
-		return;
+		return FALSE;
 	}
 
 	if (ft->save_func (sm, &internal_error)) {
@@ -864,3 +892,241 @@ schematic_get_lowest_available_refdes2 (Schematic *schematic, char *prefix)
 }
 */
 
+static void
+schematic_render (Schematic *sm, cairo_t *cr)
+{
+	NodeStore *store;
+
+	store = schematic_get_store (sm);
+
+	node_store_print_items (store, cr, &sm->priv->colors);
+	node_store_print_labels (store, cr, NULL);
+}
+
+void
+schematic_export (Schematic *sm, const gchar *filename,
+	gint img_w, gint img_h, int bg, int format)
+{
+	ArtDRect bbox;
+	NodeStore *store;
+	cairo_surface_t *surface;
+	cairo_t *cr;
+	gdouble w, h;
+	gdouble graph_w, graph_h;
+	gdouble scale, scalew, scaleh;
+
+	store = schematic_get_store (sm);
+	node_store_get_bounds (store, &bbox);
+
+	w = bbox.x1 - bbox.x0;
+	h = bbox.y1 - bbox.y0;
+
+	switch (format) {
+#ifdef CAIRO_HAS_SVG_SURFACE
+		case 0:
+			surface = cairo_svg_surface_create (filename, img_w, img_h);
+		break;
+#endif
+#ifdef CAIRO_HAS_PDF_SURFACE
+		case 1:
+			surface = cairo_pdf_surface_create (filename, img_w, img_h);
+		break;
+#endif
+#ifdef CAIRO_HAS_PS_SURFACE
+		case 2:
+			surface = cairo_ps_surface_create (filename, img_w, img_h);
+		break;
+#endif
+		default:
+			surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24, img_w, img_h);
+	}
+	cr = cairo_create (surface);
+
+	/* Background */
+	switch (bg) {
+		case 1: /* White */
+			cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
+			cairo_rectangle (cr, 0, 0, img_w, img_h);
+			cairo_fill (cr);
+			break;
+		case 2: /* Black */
+			cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+			cairo_rectangle (cr, 0, 0, img_w, img_h);
+			cairo_fill (cr);
+	}
+
+	graph_w = img_w * 0.8;
+	graph_h = img_h * 0.8;
+	scalew = graph_w / (bbox.x1 - bbox.x0);
+	scaleh = graph_h / (bbox.y1 - bbox.y0);
+	if (scalew < scaleh)
+		scale = scalew;
+	else
+		scale = scaleh;
+
+	/* Preparing ...*/
+	cairo_save (cr);
+	cairo_translate (cr, (img_w - graph_w)/2.0, (img_h - graph_h) / 2.0);
+	cairo_scale (cr, scale, scale);	
+	cairo_translate (cr, -bbox.x0, -bbox.y0);
+	cairo_set_line_width (cr, 0.5);
+
+	/* Render ... */
+	schematic_render (sm, cr);
+
+	cairo_restore (cr);
+	cairo_show_page (cr);
+
+	/* Saving ... */
+	if (format >= 3)
+		cairo_surface_write_to_png (surface, filename);
+	cairo_destroy (cr);
+	cairo_surface_destroy (surface);
+}
+
+static void
+draw_rotule (Schematic *sm, cairo_t *cr)
+{
+	cairo_save (cr);
+		cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+		cairo_set_line_width (cr, 0.5);
+		cairo_rectangle (cr, 0, 0, 180, 20);
+		cairo_rectangle (cr, 0, 20, 180, 10);
+		cairo_stroke (cr);
+	cairo_restore (cr);
+}
+
+static void
+draw_page (GtkPrintOperation *operation,
+	GtkPrintContext *context, int page_nr, Schematic *sm)
+{
+	PangoLayout *layout;
+	PangoFontDescription *desc;
+	NodeStore *store;
+	ArtDRect bbox;
+	gdouble page_w, page_h;
+	gdouble circuit_w, circuit_h;
+	
+	page_w = gtk_print_context_get_width (context);
+	page_h = gtk_print_context_get_height (context);
+
+	circuit_w = page_w * 0.8;
+	circuit_h = page_h * 0.8;
+
+	cairo_t *cr = gtk_print_context_get_cairo_context (context);
+
+	/* Draw a red rectangle, as wide as the paper (inside the margins) */
+	cairo_save (cr);
+		cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+		cairo_set_line_width (cr, 0.5);
+		cairo_rectangle (cr, 20, 10, page_w-30, page_h-20);
+		cairo_stroke (cr);
+	cairo_restore (cr);
+
+	cairo_save (cr);
+		cairo_translate (cr, page_w-190, page_h-40);
+		draw_rotule (sm, cr);
+	cairo_restore (cr);
+
+	store = schematic_get_store (sm);
+
+	node_store_get_bounds (store, &bbox);
+
+	cairo_save (cr);
+		cairo_set_line_width (cr, 0.5);
+		cairo_set_source_rgb (cr, 0, 0, 0);
+		cairo_translate (cr, page_w * 0.1, page_h * 0.1);
+		/* 0.4 is the convert factor between Model unit and
+		 * milimeters, unit used in printing
+		 */
+		cairo_scale (cr, 0.4, 0.4);	
+		cairo_translate (cr, -bbox.x0, -bbox.y0);
+		schematic_render (sm, cr);
+	cairo_restore (cr);
+}
+
+static GObject*
+print_options (GtkPrintOperation *operation, Schematic *sm)
+{
+	GladeXML *gui;
+
+	if (!g_file_test (OREGANO_GLADEDIR "/print-options.glade2", G_FILE_TEST_EXISTS)) {
+		return G_OBJECT (gtk_label_new (_("Error loading print-options.glade2")));
+	}
+
+	gui = glade_xml_new (OREGANO_GLADEDIR "/print-options.glade2",
+		"widget", GETTEXT_PACKAGE);
+	if (!gui) {
+		return G_OBJECT (gtk_label_new (_("Error loading print-options.glade2")));
+	}
+
+	if (sm->priv->printoptions)
+		g_free (sm->priv->printoptions);
+	sm->priv->printoptions = g_new0(SchematicPrintOptions, 1);
+
+	sm->priv->printoptions->components = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_components"));
+	sm->priv->printoptions->labels = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_labels"));
+	sm->priv->printoptions->wires = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_wires"));
+	sm->priv->printoptions->text = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_text"));
+	sm->priv->printoptions->background = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_background"));
+
+	/* Set default colors */
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_components")),
+		&sm->priv->colors.components);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_labels")),
+		&sm->priv->colors.labels);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_wires")),
+		&sm->priv->colors.wires);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_text")),
+		&sm->priv->colors.text);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (glade_xml_get_widget (gui, "color_background")),
+		&sm->priv->colors.background);
+
+	return glade_xml_get_widget (gui, "widget");
+}
+
+static void
+read_print_options(GtkPrintOperation *operation, GtkWidget *widget, Schematic *sm)
+{
+	SchematicPrintOptions *colors = sm->priv->printoptions;
+
+	gtk_color_button_get_color (colors->components, &sm->priv->colors.components);
+	gtk_color_button_get_color (colors->labels, &sm->priv->colors.labels);
+	gtk_color_button_get_color (colors->wires, &sm->priv->colors.wires);
+	gtk_color_button_get_color (colors->text, &sm->priv->colors.text);
+	gtk_color_button_get_color (colors->background, &sm->priv->colors.background);
+
+	g_free (sm->priv->printoptions);
+	sm->priv->printoptions = NULL;
+}
+
+void
+schematic_print (Schematic *sm, GtkPageSetup *page, GtkPrintSettings *settings, gboolean preview)
+{
+	GtkPrintOperation *op;
+	GtkPrintOperationResult res;
+
+	op = gtk_print_operation_new ();
+
+	gtk_print_operation_set_print_settings (op, settings);
+	gtk_print_operation_set_default_page_setup (op, page);
+	gtk_print_operation_set_n_pages (op, 1);
+	gtk_print_operation_set_unit (op, GTK_UNIT_MM);
+	gtk_print_operation_set_use_full_page (op, TRUE);
+
+	g_signal_connect (op, "create-custom-widget", G_CALLBACK (print_options), sm);
+	g_signal_connect (op, "custom-widget-apply", G_CALLBACK (read_print_options), sm);
+	g_signal_connect (op, "draw_page", G_CALLBACK (draw_page), sm);
+
+	gtk_print_operation_set_custom_tab_label (op, _("Schematic"));
+
+	if (preview)
+		res = gtk_print_operation_run (op, GTK_PRINT_OPERATION_ACTION_PREVIEW,
+		NULL, NULL);
+	else
+		res = gtk_print_operation_run (op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
+		NULL, NULL);
+
+	if (res == GTK_PRINT_OPERATION_RESULT_CANCEL) {
+	}
+}
