@@ -37,7 +37,7 @@
 #include "wire.h"
 #include "wire-private.h"
 #include "clipboard.h"
-#include "print.h"
+#include "schematic-print-context.h"
 
 static void      wire_class_init (WireClass *klass);
 static void      wire_init (Wire *wire);
@@ -49,7 +49,7 @@ static void      wire_flip (ItemData *data, gboolean horizontal,
 static void      wire_unregister (ItemData *data);
 static int       wire_register (ItemData *data);
 static gboolean  wire_has_properties (ItemData *data);
-static void	 wire_print (ItemData *data, OreganoPrintContext *opc);
+static void      wire_print (ItemData *data, cairo_t *cr, SchematicPrintContext *ctx);
 
 enum {
 	CHANGED,
@@ -393,9 +393,9 @@ wire_rotate (ItemData *data, int angle, SheetPos *center)
 	priv = wire->priv;
 
 	if (priv->direction == WIRE_DIR_VERT) {
-		priv->direction == WIRE_DIR_HORIZ;
+		priv->direction = WIRE_DIR_HORIZ;
 	} else if (priv->direction == WIRE_DIR_HORIZ) {
-		priv->direction == WIRE_DIR_VERT;
+		priv->direction = WIRE_DIR_VERT;
 	}
 
 	art_affine_rotate (affine, angle);
@@ -610,7 +610,7 @@ wire_register (ItemData *data)
 }
 
 static void
-wire_print (ItemData *data, OreganoPrintContext *opc)
+wire_print (ItemData *data, cairo_t *cr, SchematicPrintContext *ctx)
 {
 	SheetPos start_pos, end_pos;
 	Wire *wire;
@@ -623,17 +623,18 @@ wire_print (ItemData *data, OreganoPrintContext *opc)
 	wire_get_start_pos (wire, &start_pos);
 	wire_get_end_pos (wire, &end_pos);
 
-	gnome_print_setlinewidth (opc->ctx, 0);
-	gnome_print_moveto (opc->ctx, start_pos.x, start_pos.y);
-	gnome_print_lineto (opc->ctx, end_pos.x, end_pos.y);
-	gnome_print_stroke (opc->ctx);
+	cairo_save (cr);
+		gdk_cairo_set_source_color (cr, &ctx->colors.wires);
+		cairo_move_to (cr, start_pos.x, start_pos.y);
+		cairo_line_to (cr, end_pos.x, end_pos.y);
+		cairo_stroke (cr);
+	cairo_restore (cr);
 }
 
 void wire_delete (Wire *wire)
 {
 	g_return_if_fail (IS_WIRE (wire));
 
-	g_print ("Listo\n");
 	g_signal_emit_by_name (G_OBJECT (wire), "delete");
 }
 
