@@ -1,20 +1,23 @@
 /*
  * oregano-config.h
  *
- * 
- * Author: 
+ *
+ * Author:
  *  Richard Hult <rhult@hem.passagen.se>
- * 
- *  http://www.dtek.chalmers.se/~d4hult/oregano/ 
- * 
- * Copyright (C) 1999,2000  Richard Hult 
- * 
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the 
- * License, or (at your option) any later version. 
- * 
- * This program is distributed in the hope that it will be useful, 
+ *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
+ *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *
+ * Web page: http://arrakis.lug.fi.uba.ar/
+ *
+ * Copyright (C) 1999-2001  Richard Hult
+ * Copyright (C) 2003,2004  LUGFI
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
@@ -27,14 +30,16 @@
 #ifndef __OREGANO_CONFIG_H
 #define __OREGANO_CONFIG_H
 
+#include "splash.h"
+
 void oregano_config_load (void);
 void oregano_config_save (void);
 
-/* 
+/*
  * Feb 2000, Elker Cavina <e.cavina@libero.it>
- * perhaps make the oregano global variable pass through these functions ? 
+ * perhaps make the oregano global variable pass through these functions ?
  */
 
-void oregano_lookup_libraries (void);
+void oregano_lookup_libraries (Splash *sp);
 
 #endif
