@@ -36,7 +36,6 @@
 #include "file.h"
 #include "main.h"
 #include "schematic.h"
-#include "sim-engine.h"
 #include "dialogs.h"
 #include "plot.h"
 #include "smallicon.h"
@@ -66,26 +65,19 @@ const gchar *UPSCRIPT_FONT = N_("Sans 8");
 #define PLOT_AXIS_COLOR "black"
 #define PLOT_CURVE_COLOR "medium sea green"
 
-static int n_curve_colors = 6;
+static guint next_color = 0;
+static guint n_curve_colors = 7;
 static char *plot_curve_colors[] = {
 	"white",
-	"blue",
 	"green",
 	"red",
 	"yellow",
 	"cyan",
+	"pink",
+	"orange1",
 	0
 };
 
-/*static RGB plot_curve_colors_rgb[] = {
-	{1, 1, 1},
-	{0, 0, 1},
-	{0, 1, 0},
-	{1, 0, 0},
-	{1, 1, 0},
-	{0, 1, 1}
-};*/
-
 /* Hack! */
 #ifndef G_FUNC
 #define G_FUNC(x) (x)
@@ -101,7 +93,7 @@ typedef struct {
 
 	gboolean show_cursor;
 
-	SimEngine *sim;
+	OreganoEngine *sim;
 	SimulationData *current;
 
 	gboolean logx;
@@ -134,10 +126,8 @@ static void destroy_window (GtkWidget *widget, Plot *plot);
 static void zoom_100 (GtkWidget *widget, Plot *plot);
 static void zoom_region (GtkWidget *widget, Plot *plot);
 static void zoom_pan (GtkWidget *widget, Plot *plot);
-static void destroy_plot (Plot *plot);
 static gint delete_event_cb (GtkWidget *widget, GdkEvent *event, Plot *plot);
 static void plot_canvas_movement(GtkWidget *, GdkEventMotion *, Plot *);
-static void plot_draw_axis (Plot *, AxisType, double, double);
 
 static void plot_toggle_cross (GtkWidget *widget, Plot *plot);
 static void plot_export (GtkWidget *widget, Plot *plot);
@@ -146,13 +136,13 @@ static void add_function (GtkWidget *widget, Plot *plot);
 
 static GnomeUIInfo plot_file_menu[] =
 {
-	GNOMEUIINFO_MENU_PRINT_ITEM(NULL,NULL),
+	/*GNOMEUIINFO_MENU_PRINT_ITEM(NULL,NULL),
 	GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(NULL,NULL),
 	GNOMEUIINFO_ITEM_NONE(N_("Print Preview"),
 		N_("Preview the plot before printing"), NULL),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_NONE(N_("Export plot"),
-		N_("Show the export menu"), plot_export),
+		N_("Show the export menu"), plot_export),*/
 	GNOMEUIINFO_ITEM_NONE(N_("Add Function"),
 		N_("Add new function to the graph"), add_function),
 	GNOMEUIINFO_SEPARATOR,
@@ -195,8 +185,8 @@ static GnomeUIInfo plot_help_menu[] =
 
 GnomeUIInfo plot_main_menu[] = {
 	GNOMEUIINFO_SUBTREE(N_("_File"), plot_file_menu),
-	GNOMEUIINFO_SUBTREE(N_("_Plot"), plot_plot_menu),
-	GNOMEUIINFO_MENU_HELP_TREE (plot_help_menu),
+	/*GNOMEUIINFO_SUBTREE(N_("_Plot"), plot_plot_menu),*/
+	/*GNOMEUIINFO_MENU_HELP_TREE (plot_help_menu),*/
 	GNOMEUIINFO_END
 };
 
@@ -227,9 +217,8 @@ gchar *tmp;
 static gint
 delete_event_cb (GtkWidget *widget, GdkEvent *event, Plot *plot)
 {
-	g_object_unref(plot->sim);
 	plot->window = NULL;
-	g_object_unref(plot->sim);
+	g_object_unref (plot->sim);
 	if (plot->ytitle) g_free(plot->ytitle);
 	g_free(plot);
 	plot = NULL;
@@ -242,10 +231,10 @@ destroy_window(GtkWidget *widget, Plot *plot)
 {
 	/* TODO - chequear si no hay que destruir el combo box */
 	gtk_widget_destroy (plot->window);
-	g_object_unref(plot->sim);
+	g_object_unref (plot->sim);
 	plot->window = NULL;
-	if (plot->ytitle) g_free(plot->ytitle);
-	g_free(plot);
+	if (plot->title) g_free (plot->title);
+	g_free (plot);
 	plot = NULL;
 }
 
@@ -276,6 +265,7 @@ on_plot_selected (GtkCellRendererToggle *cell_renderer, gchar *path, Plot *plot)
 static GPlotFunction*
 create_plot_function_from_simulation_data (guint i, SimulationData *current)
 {
+	GPlotFunction *f;
 	double *X;
 	double *Y;
 	double data;
@@ -296,7 +286,10 @@ create_plot_function_from_simulation_data (guint i, SimulationData *current)
 		X[j] = data;
 	}
 
-	return g_plot_lines_new (X, Y, len);
+	f = g_plot_lines_new (X, Y, len);
+	g_object_set (G_OBJECT (f), "color", plot_curve_colors[(next_color++)%n_curve_colors], NULL);
+
+	return f;
 }
 
 static void
@@ -317,9 +310,10 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 	ca = gtk_entry_get_text (GTK_ENTRY (entry));
 
 	plot->current = NULL;
-	for (analysis = plot->sim->analysis; analysis; analysis = analysis->next) {
+	analysis = oregano_engine_get_results (plot->sim);
+	for (; analysis; analysis = analysis->next) {
 		sdat = SIM_DATA (analysis->data);
-		if (!strcmp (ca, sim_engine_analysis_name (sdat))) {
+		if (!strcmp (ca, oregano_engine_get_analysis_name (sdat))) {
 			plot->current = sdat;
 			break;
 		}
@@ -338,7 +332,7 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 
 	g_free (plot->title);
 	plot->title = g_strdup_printf (_("Plot - %s"),
-		sim_engine_analysis_name (plot->current));
+		oregano_engine_get_analysis_name (plot->current));
 
 	/*  Set the variable names in the list  */
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
@@ -360,8 +354,12 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 
 		if (plot->current->type != DC_TRANSFER) {
 			if (strchr(plot->current->var_names[i], '#') == NULL) {
+				gchar *color;
+
 				f = create_plot_function_from_simulation_data (i, plot->current);
 				g_object_set (G_OBJECT (f), "visible", FALSE, NULL);
+				g_object_get (G_OBJECT (f), "color", &color, NULL);
+
 				g_plot_add_function (GPLOT (plot->plot), f);
 				gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &parent_nodes);
 				gtk_tree_store_set (GTK_TREE_STORE (model),
@@ -369,20 +367,24 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 				 	0, FALSE, 
 					1, plot->current->var_names[i],
 				 	2, TRUE,
-					3, "white",
+					3, color,
 					4, f,
 					-1);
 			}
 		} else {
+			gchar *color;
+
 			f = create_plot_function_from_simulation_data (i, plot->current);
 			g_object_set (G_OBJECT (f), "visible", FALSE, NULL);
+			g_object_get (G_OBJECT (f), "color", &color, NULL);
+
 			g_plot_add_function (GPLOT (plot->plot), f);
 			gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &parent_nodes);
 			gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
 				0, FALSE, 
 				1, plot->current->var_names[i],
 			 	2, TRUE,
-				3, "white",
+				3, color,
 				4, f,
 			 	-1);
 		}
@@ -471,10 +473,6 @@ plot_window_create (Plot *plot)
 	g_signal_connect(G_OBJECT(button), "clicked",
 		G_CALLBACK(destroy_window), plot);
 
-	button = glade_xml_get_widget (gui, "close");
-	g_signal_connect(G_OBJECT(button), "clicked",
-		G_CALLBACK(destroy_window), plot);
-
 	button = glade_xml_get_widget (gui, "zoom_panning");
 	g_signal_connect(G_OBJECT(button), "clicked",
 		G_CALLBACK(zoom_pan), plot);
@@ -514,7 +512,7 @@ plot_window_create (Plot *plot)
 
 	gtk_widget_realize(GTK_WIDGET(window));
 	
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (plot_plot_menu[1].widget), TRUE);
+	//gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (plot_plot_menu[1].widget), TRUE);
 
 	plot->combobox = glade_xml_get_widget (gui, "analysis_combo");
 	plot->window = window;
@@ -524,7 +522,7 @@ plot_window_create (Plot *plot)
 }
 
 int
-plot_show (SimEngine *engine)
+plot_show (OreganoEngine *engine)
 {
 	GtkEntry *entry;
 	GtkTreeView *list;
@@ -535,11 +533,10 @@ plot_show (SimEngine *engine)
 	SimulationData *first = NULL;
 
 	g_return_val_if_fail (engine != NULL, FALSE);
-	g_return_val_if_fail (IS_SIM_ENGINE (engine), FALSE);
 
 	plot = g_new0(Plot, 1);
 
-	g_object_ref(engine);
+	g_object_ref (engine);
 	plot->sim = engine;
 	plot->window = plot_window_create(plot);
 
@@ -551,13 +548,14 @@ plot_show (SimEngine *engine)
 
 	plot->show_cursor = TRUE;
 
+	next_color = 0;
+
 	/*  Get the analysis we have */
-	analysis = engine->analysis;
+	analysis = oregano_engine_get_results (engine);
 	for (; analysis ; analysis = analysis->next) {
 		SimulationData *sdat = SIM_DATA (analysis->data);
-		gchar *str = sim_engine_analysis_name (sdat);
+		gchar *str = oregano_engine_get_analysis_name (sdat);
 		if (sdat->type == OP_POINT) {
-			free (str);
 			continue;
 		}
 		if (s_current == NULL) {
@@ -597,6 +595,7 @@ plot_toggle_cross (GtkWidget *widget, Plot *plot)
 static GPlotFunction*
 create_plot_function_from_data (SimulationFunction *func, SimulationData *current)
 {
+	GPlotFunction *f;
 	double *X;
 	double *Y;
 	double data;
@@ -610,12 +609,28 @@ create_plot_function_from_data (SimulationFunction *func, SimulationData *curren
 		Y[j] = g_array_index (current->data[func->first], double, j);
 	
 		data = g_array_index (current->data[func->second], double, j);
-		Y[j] = sim_engine_do_function (func->type, Y[j], data);
+		switch (func->type) {
+			case FUNCTION_MINUS:
+				Y[j] -= data;
+			break;
+			case FUNCTION_TRANSFER:
+				if (data < 0.000001f) {
+					if (Y[j] < 0)
+						Y[j] = -G_MAXDOUBLE;
+					else
+						Y[j] = G_MAXDOUBLE;
+				} else {
+					Y[j] /= data;
+				}
+		}
 		
 		X[j] = g_array_index (current->data[0], double, j);
 	}
 
-	return g_plot_lines_new (X, Y, len);
+	f = g_plot_lines_new (X, Y, len);
+	g_object_set (G_OBJECT (f), "color", plot_curve_colors[(next_color++)%n_curve_colors], NULL);
+
+	return f;
 }
 
 static void
@@ -626,6 +641,7 @@ add_function (GtkWidget *widget, Plot *plot)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GList *lst;
+	gchar *color;
 
 	plot_add_function_show (plot->sim, plot->current);
 
@@ -666,11 +682,12 @@ add_function (GtkWidget *widget, Plot *plot)
 		}
 
 		f = create_plot_function_from_data (func, plot->current);
+		g_object_get (G_OBJECT (f), "color", &color, NULL);
 
 		g_plot_add_function (GPLOT (plot->plot), f);
 
 		gtk_tree_store_append(GTK_TREE_STORE(model), &child, &iter);
-		gtk_tree_store_set(GTK_TREE_STORE(model), &child, 0, TRUE, 1, str, 2, TRUE, 3, "white", 4, f, -1);
+		gtk_tree_store_set(GTK_TREE_STORE(model), &child, 0, TRUE, 1, str, 2, TRUE, 3, color, 4, f, -1);
 
 		lst = lst->next;
 	}
