@@ -36,6 +36,7 @@
 #include <libgnomeui/gnome-app.h>
 #include <libbonobo-2.0/libbonobo.h>
 #include <sys/time.h>
+#include <cairo/cairo-features.h>
 
 #include "sheet-private.h"
 #include "schematic-view.h"
@@ -54,7 +55,6 @@
 #include "sim-settings.h"
 #include "simulation.h"
 #include "smallicon.h"
-#include "print.h"
 #include "plot.h"
 #include "sheet-item-factory.h"
 #include "part-item.h"
@@ -113,7 +113,8 @@ struct _SchematicViewPriv {
 	GHashTable *dots;
 
 	RubberbandInfo *rubberband;
-	PageProperties page;
+	GtkPageSetup *page_setup;
+	GtkPrintSettings *print_settings;
 
 	GList *preserve_selection_items;
 
@@ -301,55 +302,124 @@ properties_cmd (GtkWidget *widget, SchematicView *sv)
 }
 
 static void
-page_properties_cmd (GtkWidget *widget, SchematicView *sv)
+find_file (GtkButton *btn, GtkEntry *text)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_file_chooser_dialog_new (
+		_("Export to..."),
+		NULL,
+		GTK_FILE_CHOOSER_ACTION_SAVE,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+		NULL);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		char *filename;
+
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		gtk_entry_set_text (text, filename);
+		g_free (filename);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
+static void
+export_cmd (GtkWidget *widget, SchematicView *sv)
 {
 	Schematic *s;
 	GladeXML *xml;
 	GtkWidget *win;
-	GtkCheckButton *fit, *center_h, *center_v;
+	GtkWidget *w;
+	GtkEntry *file;
+	GtkComboBox *combo;
 	gint btn;
+	gint formats[5], fc;
 
 	s = schematic_view_get_schematic (sv);
 		
-	if (!g_file_test (OREGANO_GLADEDIR "/page-properties.glade2", G_FILE_TEST_EXISTS)) {
+	if (!g_file_test (OREGANO_GLADEDIR "/export.glade2", G_FILE_TEST_EXISTS)) {
 		gchar *msg;
 		msg = g_strdup_printf (
 			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
-			OREGANO_GLADEDIR "/page-properties.glade2");
+			OREGANO_GLADEDIR "/export.glade2");
 
-		oregano_error_with_title (_("Could not create the page properties dialog"), msg);
+		oregano_error_with_title (_("Could not create properties dialog"), msg);
 		g_free (msg);
 		return;
 	}
 
 	xml = glade_xml_new (
-		OREGANO_GLADEDIR "/page-properties.glade2",
-		"page_properties", NULL
+		OREGANO_GLADEDIR "/export.glade2",
+		"export", NULL
 	);
 
-	win = glade_xml_get_widget (xml, "page_properties");
+	win = glade_xml_get_widget (xml, "export");
+	combo = GTK_COMBO_BOX (glade_xml_get_widget (xml, "format"));
 
-	// Set the checkboxes according to the options selected
-	fit = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "fit_page"));
-	center_h = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "center_h"));
-	center_v = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "center_v"));
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (combo)));
+	fc = 0;
+#ifdef CAIRO_HAS_SVG_SURFACE
+	gtk_combo_box_append_text (combo, "Scalar Vector Graphics (SVG)");
+	formats[fc++] = 0;
+#endif
+#ifdef CAIRO_HAS_PDF_SURFACE
+	gtk_combo_box_append_text (combo, "Portable Document Format (PDF)");
+	formats[fc++] = 1;
+#endif
+#ifdef CAIRO_HAS_PS_SURFACE
+	gtk_combo_box_append_text (combo, "Postscript (PS)");
+	formats[fc++] = 2;
+#endif
+#ifdef CAIRO_HAS_PNG_FUNCTIONS
+	gtk_combo_box_append_text (combo, "Portable Network Graphics (PNG)");
+	formats[fc++] = 3;
+#endif
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fit), sv->priv->page.fit_to_page);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (center_h), sv->priv->page.center_h);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (center_v), sv->priv->page.center_v);
-	
+	file = GTK_ENTRY (glade_xml_get_widget (xml, "file"));
+
+	w = glade_xml_get_widget (xml, "find");
+	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (find_file), file);
+
+	gtk_combo_box_set_active (combo, 0);
 	btn = gtk_dialog_run (GTK_DIALOG (win));
 
-	// Store the changes
 	if (btn == GTK_RESPONSE_OK) {
-		sv->priv->page.fit_to_page = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fit));
-		sv->priv->page.center_h = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (center_h));
-		sv->priv->page.center_v = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (center_v));
+		int bg = 0;
+		GtkSpinButton *spinw, *spinh;
+		GtkWidget *w;
+		int i = gtk_combo_box_get_active (combo);
+
+		w = glade_xml_get_widget (xml, "bgwhite");
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
+			bg = 1;
+		w = glade_xml_get_widget (xml, "bgblack");
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
+			bg = 2;
+
+		spinw = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "export_width"));
+		spinh = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "export_height"));
+
+		schematic_export (s,
+			gtk_entry_get_text (file),
+			gtk_spin_button_get_value_as_int (spinw),
+			gtk_spin_button_get_value_as_int (spinh),
+			bg,
+			formats[i]);
 	}
 
 	gtk_widget_destroy (win);
 }
 
+static void
+page_properties_cmd (GtkWidget *widget, SchematicView *sv)
+{
+  sv->priv->page_setup = gtk_print_run_page_setup_dialog (NULL,
+			sv->priv->page_setup,
+			sv->priv->print_settings);
+}
+
 static void
 open_cmd (GtkWidget *widget, SchematicView *sv)
 {
@@ -607,13 +677,17 @@ show_label_cmd (GtkCheckMenuItem *toggle, SchematicView *sv)
 static void
 print_cmd (GtkWidget *widget, SchematicView *sv)
 {
-	print_schematic (G_OBJECT (sv), FALSE);
+	schematic_print (schematic_view_get_schematic (sv),
+		sv->priv->page_setup,
+		sv->priv->print_settings, FALSE);
 }
 
 static void
 print_preview_cmd (GtkWidget *widget, SchematicView *sv)
 {
-	print_schematic (G_OBJECT (sv), TRUE);
+	schematic_print (schematic_view_get_schematic (sv),
+		sv->priv->page_setup,
+		sv->priv->print_settings, TRUE);
 }
 
 static void
@@ -935,6 +1009,8 @@ schematic_view_init (SchematicView *sv)
 	sv->priv->items = NULL;
 	sv->priv->empty = TRUE;
 	sv->priv->schematic = NULL;
+	sv->priv->page_setup = NULL;
+	sv->priv->print_settings = gtk_print_settings_new ();
 
 	sv->priv->show_voltmeters = FALSE;
 	sv->priv->voltmeter_items = NULL;
@@ -2687,8 +2763,3 @@ schematic_view_update_parts (SchematicView *sv)
 	}
 }
 
-PageProperties *
-schematic_view_get_page_properties (SchematicView *sv)
-{
-	return &(sv->priv->page);
-}
